@@ -19,4 +19,10 @@ package operator
 
 type ToolsOperator interface {
 	ReflectGetValue(instance interface{}, filters []interface{}) interface{}
+	GetEnvValue(key string) string
+	ParseFloat(val string, bitSize int) (float64, error)
+	ParseBool(val string) bool
+	ParseInt(val string, base, bitSize int) (int64, error)
+	Atoi(val string) (int, error)
+	NewSyncMap() interface{}
 }
