@@ -19,8 +19,13 @@ package plugins
 
 import (
 	traceactivation "github.com/apache/skywalking-go/plugin/trace"
+	"github.com/apache/skywalking-go/plugins/amqp"
 	"github.com/apache/skywalking-go/plugins/core/instrument"
 	"github.com/apache/skywalking-go/plugins/dubbo"
+	"github.com/apache/skywalking-go/plugins/echov4"
+	fasthttp_client "github.com/apache/skywalking-go/plugins/fasthttp/hostclient"
+	fasthttp_router "github.com/apache/skywalking-go/plugins/fasthttp/router"
+	"github.com/apache/skywalking-go/plugins/fiber"
 	"github.com/apache/skywalking-go/plugins/gin"
 	goredisv9 "github.com/apache/skywalking-go/plugins/go-redisv9"
 	"github.com/apache/skywalking-go/plugins/go-restfulv3"
@@ -33,6 +38,7 @@ import (
 	"github.com/apache/skywalking-go/plugins/microv4"
 	"github.com/apache/skywalking-go/plugins/mongo"
 	"github.com/apache/skywalking-go/plugins/mux"
+	"github.com/apache/skywalking-go/plugins/rocketmq"
 	runtime_metrics "github.com/apache/skywalking-go/plugins/runtimemetrics"
 	sql_entry "github.com/apache/skywalking-go/plugins/sql/entry"
 	sql_mysql "github.com/apache/skywalking-go/plugins/sql/mysql"
@@ -55,6 +61,13 @@ func init() {
 	registerFramework(grpc.NewInstrument())
 	registerFramework(irisv12.NewInstrument())
 	registerFramework(traceactivation.NewInstrument())
+	registerFramework(fiber.NewInstrument())
+	registerFramework(rocketmq.NewInstrument())
+	registerFramework(amqp.NewInstrument())
+
+	// fasthttp related instruments
+	registerFramework(fasthttp_client.NewInstrument())
+	registerFramework(fasthttp_router.NewInstrument())
 
 	// gorm related instruments
 	registerFramework(gorm_entry.NewInstrument())
@@ -63,6 +76,9 @@ func init() {
 	// sql related instruments
 	registerFramework(sql_entry.NewInstrument())
 	registerFramework(sql_mysql.NewInstrument())
+
+	// echov4 related instruments
+	registerFramework(echov4.NewInstrument())
 }
 
 func registerFramework(ins instrument.Instrument) {
