@@ -292,6 +292,8 @@ func (i *ImportAnalyzer) analyzeFieldImport(filePath string, exp dst.Expr) {
 		i.analyzeFieldImport(filePath, n.Elt)
 	case *dst.StarExpr:
 		i.analyzeFieldImport(filePath, n.X)
+	case *dst.ChanType:
+		i.analyzeFieldImport(filePath, n.Value)
 	}
 }
 
