@@ -22,7 +22,7 @@ var basicDataTypes = make(map[string]bool)
 func init() {
 	types := []string{
 		"bool", "int8", "int16", "int32", "int64", "uint8", "uint16", "uint32", "uint64", "int", "uint", "uintptr",
-		"float32", "float64", "complex64", "complex128", "string", "error", "interface{}", "_", "byte",
+		"float32", "float64", "complex64", "complex128", "string", "error", "interface{}", "_", "byte", "any",
 	}
 	for _, tp := range types {
 		basicDataTypes[tp] = true
